#ifndef NT2_INCLUDE_FUNCTIONS_ANY_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ANY_HPP_INCLUDED

#include <nt2/reduction/include/functions/any.hpp>

#endif
